==> magento-module-media-gallery-ui-1.0.0.zip: view/adminhtml/web/js/directory/actions/createDirectory.js <==
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
define([
    'jquery'
], function ($) {
    'use strict';

    return function (createFolderUrl, paths) {
        var deferred = $.Deferred(),
            message,
            data = {
                paths: paths
            };

        $.ajax({
            type: 'POST',
            url: createFolderUrl,
            dataType: 'json',
            showLoader: true,
            data: data,
            context: this,

            /**
             * Resolve  if success, reject with response message othervise
             *
             * @param {Object} response
             */
            success: function (response) {
                if (response.success) {
                    deferred.resolve(response.message);

                    return;
                }

                deferred.reject(response.message);
            },

            /**
             * Extract the message and reject
             *
             * @param {Object} response
             */
            error: function (response) {

                if (typeof response.responseJSON === 'undefined' ||
                    typeof response.responseJSON.message === 'undefined'
                ) {
                    message = $.mage.__('Could not create the directory.');
                } else {
                    message = response.responseJSON.message;
                }
                deferred.reject(message);
            }
        });

        return deferred.promise();
    };
});

==> magento-module-media-gallery-ui-100.4.4.zip: view/adminhtml/web/js/directory/actions/createDirectory.js <==
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
define([
    'jquery',
    'mage/translate'
], function ($, $t) {
    'use strict';

    return function (createFolderUrl, paths) {
        var deferred = $.Deferred(),
            message,
            data = {
                paths: paths
            };

        $.ajax({
            type: 'POST',
            url: createFolderUrl,
            dataType: 'json',
            showLoader: true,
            data: data,
            context: this,

            /**
             * Resolve  if success, reject with response message othervise
             *
             * @param {Object} response
             */
            success: function (response) {
                if (response.success) {
                    deferred.resolve(response.message);

                    return;
                }

                deferred.reject(response.message);
            },

            /**
             * Extract the message and reject
             *
             * @param {Object} response
             */
            error: function (response) {

                if (typeof response.responseJSON === 'undefined' ||
                    typeof response.responseJSON.message === 'undefined'
                ) {
                    message = $t('Could not create the directory.');
                } else {
                    message = response.responseJSON.message;
                }
                deferred.reject(message);
            }
        });

        return deferred.promise();
    };
});
